pub struct ExampleEvent<'a> { /* private fields */ }Expand description
Sample event generated using event! macro.
Implementations
Sourceimpl<'a> ExampleEvent<'a>
impl<'a> ExampleEvent<'a>
Sourcepub fn subscribe<F>(&mut self, handler: F) -> Subscription
pub fn subscribe<F>(&mut self, handler: F) -> Subscription
Subscribes a closure to be called on event emmision.
Return subscription token.
Sourcepub fn unsubscribe(
&mut self,
subscription: Subscription,
) -> Result<(), SubscriptionMissing>
pub fn unsubscribe( &mut self, subscription: Subscription, ) -> Result<(), SubscriptionMissing>
Unsubscribes handler for given subscription token.
Returns error if there is no handler for given subscription.